@@ -1,8 +1,9 @@
-from Products.CMFCore.utils import getToolByName
 from datetime import datetime, timedelta
 from plone.memoize import ram
+from Products.CMFCore.utils import getToolByName
 from zope.app.component.hooks import getSite
-from zope.i18nmessageid import MessageFactory
+from zope.globalrequest import getRequest
+from zope.i18n import translate
 import cgi
 import os.path
 
@@ -43,15 +44,17 @@ def readable_size(item, num):
 @ram.cache(lambda m, i, author: author)
 def readable_author(item, author):
     #TODO: terribly inefficient. Make some HelperCommons or something
+    site = getSite()
+    portal_url = getToolByName(site, 'portal_url')
     if not author:
         return '-'
     name = author
-    user = item.acl_users.getUserById(author)
+    user = site.acl_users.getUserById(author)
     if user is not None:
         name = user.getProperty('fullname', author) or author
         if not len(name):
             name = author
-    return '<a href="%s/author/%s">%s</a>' % (item.portal_url(), author, name)
+    return '<a href="%s/author/%s">%s</a>' % (portal_url(), author, name)
 
 
 def readable_date_time_text(item, date):
@@ -114,16 +117,20 @@ def linked(item, value, show_icon=True):
 
     type_class=''
     if show_icon:
-        plone_utils = getToolByName(getSite(), 'plone_utils')
+        site = getSite()
+        plone_utils = getToolByName(site, 'plone_utils')
+        portal_url = getToolByName(site, 'portal_url')
         img = u'<img src="%s/%s"/>' % (
-            item.portal_url(), item.getIcon)
+            portal_url(), item.getIcon)
         if not item.getIcon:
             type_class = ' class="contenttype-%s"' % \
                 plone_utils.normalizeString(item.portal_type)
+            img = u''
     else:
         img = u''
-
-    value = cgi.escape(value.decode('utf8'), quote=True)
+    if not isinstance(value, unicode):
+        value = value.decode('utf8')
+    value = cgi.escape(value, quote=True)
 
     href = url_method()
 
@@ -146,15 +153,17 @@ def linked_without_icon(item, value):
 
 
 def quick_preview(item, value):
+    portal_url = getToolByName(getSite(), 'portal_url')
     url_method = lambda: '#'
     #item = hasattr(item, 'aq_explicit') and item.aq_explicit or item
     if hasattr(item, 'getURL'):
         url_method = item.getURL
     elif hasattr(item, 'absolute_url'):
         url_method = item.absolute_url
-    img = u'<img src="%s/%s"/>' % (item.portal_url(), item.getIcon)
-
-    value = cgi.escape(value.decode('utf8'), quote=True)
+    img = u'<img src="%s/%s"/>' % (portal_url(), item.getIcon)
+    if not isinstance(value, unicode):
+        value = value.decode('utf8')
+    value = cgi.escape(value, quote=True)
 
 
     link = u'<a class="quick_preview" href="%s/quick_preview">%s%s</a>' % (
@@ -164,12 +173,8 @@ def quick_preview(item, value):
 
 
 def translated_string(domain='plone'):
-    factory = MessageFactory(domain)
-
-    def translate(item, value):
-        if not value:
-            return value
-        if not isinstance(value, unicode):
-            value = value.decode('utf8')
-        return factory(value)
-    return translate
+    domain = domain
+    def _translate(item, value):
+        return translate(
+            value, context=getRequest(), domain=domain)
+    return _translate
